@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Set::Relation; # role
-    our $VERSION = '0.012006';
+    our $VERSION = '0.012007';
     $VERSION = eval $VERSION;
     # Note: This given version applies to all of this file's packages.
 
@@ -135,7 +135,7 @@ Relation data type for Perl
 
 =head1 VERSION
 
-This document describes Set::Relation version 0.12.6 for Perl 5.
+This document describes Set::Relation version 0.12.7 for Perl 5.
 
 =head1 SYNOPSIS
 
@@ -1883,7 +1883,7 @@ I<This documentation is pending.>
 
 =head1 AUTHOR
 
-Darren Duncan (C<perl@DarrenDuncan.net>)
+Darren Duncan (C<darren@DarrenDuncan.net>)
 
 =head1 LICENSE AND COPYRIGHT
 
